Summary:          Tools for configuring and using IPSEC
Name:             ipsec-tools
Version:          0.7.3
Release:          1%{?dist}%{?pext}
License:          BSD
Group:            System Environment/Base
Source0:          http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:          racoon.init
Source2:          racoon.sysconfig
Source3:          racoon.conf
Source4:          racoon.psk
Source5:          racoon.pam
URL:              http://%{name}.sourceforge.net/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           Yvan Vanhullebus <vanhu@netasq.com>
Requires:         %{name}-libs = %{version}-%{release}
Requires:         initscripts >= 7.31.11.EL-1
Requires(pre):    /usr/sbin/groupadd
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
BuildRequires:    bison flex krb5-devel libselinux-devel
BuildRequires:    openldap-devel openssl-devel pam-devel
BuildRequires:    readline-devel

%description
IPsec-Tools is a port of the KAME Project's IPsec tools to the Linux IPsec
implementation. IPsec-Tools provides racoon, an IKE daemon; libipsec, a
PFKey implementation; and setkey, a security policy and security association
database configuration utility.


%package          devel
Summary:          Development tools for %{name}
Group:            Development/Libraries
Requires:         %{name}-libs = %{version}-%{release}
Requires:         bison flex krb5-devel libselinux-devel
Requires:         openldap-devel openssl-devel pam-devel

%description      devel
The %{name}-devel package contains the static libraries and header files
for developing software using %{name}.


%package          libs
Summary:          Libraries used by %{name}
Group:            System Environment/Libraries

%description      libs
The %{name}-libs package contains all runtime libraries used by %{name}.


%prep
%setup -q

# Prepare docs
%{__mkdir_p} doc_inst/{racoon,setkey}
%{__cp} src/racoon/doc/*             doc_inst/racoon
%{__cp} src/racoon/samples/*.sample* doc_inst/racoon
%{__cp} src/setkey/sample*           doc_inst/setkey


%build
%configure \
	--sysconfdir=%{_sysconfdir}/racoon \
	--libdir=/%{_lib}                  \
	--enable-shared                    \
	--enable-static                    \
	--enable-adminport                 \
	--enable-hybrid                    \
	--enable-frag                      \
	--enable-gssapi                    \
	--enable-dpd                       \
	--enable-fastquit                  \
	--enable-ipv6                      \
	--enable-natt                      \
	--enable-security-context          \
	--with-readline                    \
	--with-flex                        \
	--with-openssl=%{_prefix}          \
	--with-libpam                      \
	--with-libldap                     \
	--with-kernel-headers=%{_includedir}

%{__make} %{?_smp_mflags}


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{pam.d,racoon/certs,setkey.d,sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}/sbin
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/racoon

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

%{__mv}      -f      ${RPM_BUILD_ROOT}%{_sbindir}/setkey ${RPM_BUILD_ROOT}/sbin

%{__install} -m 0755 %{SOURCE1} ${RPM_BUILD_ROOT}%{_initrddir}/racoon
%{__install} -m 0644 %{SOURCE2} ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/racoon
%{__install} -m 0644 %{SOURCE5} ${RPM_BUILD_ROOT}%{_sysconfdir}/pam.d/racoon

%{__install} -m 0600 %{SOURCE3} ${RPM_BUILD_ROOT}%{_sysconfdir}/racoon/racoon.conf
%{__install} -m 0600 %{SOURCE4} ${RPM_BUILD_ROOT}%{_sysconfdir}/racoon/psk.txt

%{__rm}      -f                 ${RPM_BUILD_ROOT}/%{_lib}/lib*.so.{?,??}


%pre
if ! getent group ipsec >/dev/null 2>&1; then
  /usr/sbin/groupadd -r ipsec
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add racoon

%post libs -p /sbin/ldconfig


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service racoon stop >/dev/null 2>&1
  /sbin/chkconfig --del racoon
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service racoon condrestart >/dev/null 2>&1 || :
fi

%postun libs -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc ChangeLog* NEWS README doc_inst/*
%{_initrddir}/racoon
%config(noreplace) %{_sysconfdir}/sysconfig/racoon
%config(noreplace) %{_sysconfdir}/pam.d/racoon
%attr(750,root,ipsec) %dir %{_sysconfdir}/setkey.d
%attr(750,root,ipsec) %dir %{_sysconfdir}/racoon
%attr(700,root,root)  %dir %{_sysconfdir}/racoon/certs
%attr(600,root,root) %config(noreplace) %{_sysconfdir}/racoon/racoon.conf
%attr(600,root,root) %config(noreplace) %{_sysconfdir}/racoon/psk.txt
/sbin/setkey
%{_sbindir}/plainrsa-gen
%{_sbindir}/racoon
%{_sbindir}/racoonctl
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*
%attr(750,root,ipsec) %dir %{_localstatedir}/racoon

%files devel
%defattr(-,root,root)
/%{_lib}/libipsec.*a
/%{_lib}/libipsec.so
/%{_lib}/libracoon.*a
/%{_lib}/libracoon.so
%{_includedir}/libipsec
%{_includedir}/racoon
%{_mandir}/man3/*.3*

%files libs
%defattr(-,root,root)
/%{_lib}/libipsec.so.*
/%{_lib}/libracoon.so.*


%changelog
* Wed Dec 29 2010 Peter Pramberger <peterpramb@member.fsf.org> - 0.7.3-1
- Initial build
